@@ -27,8 +27,6 @@
 
 typedef struct guitype {
     GtkWidget       *window;
-    GtkActionGroup  *action_group;
-    GtkUIManager    *ui_manager;
     GList           *hostnamehistory;
     GList           *porthistory;
     GList           *txhistory;
@@ -53,7 +51,7 @@ typedef struct guitype {
     gchar           *high8tagname;
 } guitype;
 
-guitype *gui;
+extern guitype *gui;
 
 guitype *new_gui(void);
 void create_mainwindow(void);
@@ -103,4 +101,6 @@ gboolean on_highentry_clicked(GtkEditable       *entry,
                               GdkEventButton    *event,
                               gpointer           user_data);
 
+extern GValue grid_spacing;
+
 #endif /* XDX_GUI_H */
