@@ -61,7 +61,7 @@ void
 on_manual_activate(GtkMenuItem *menuitem,
                    gpointer     user_data)
 {
-    GtkWidget *manualdialog, *swindow, *helptextview;
+    GtkWidget *manualdialog, *swindow, *helptextview, *vbox;
     GtkTextBuffer *buffer;
     GtkTextIter iter;
     PangoFontDescription *font_desc;
@@ -69,18 +69,28 @@ on_manual_activate(GtkMenuItem *menuitem,
     FILE *in;
 
 
-    manualdialog = gtk_dialog_new_with_buttons(_("xdx - manual"),
-                   GTK_WINDOW(gui->window), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                   GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+    manualdialog = gtk_dialog_new_with_buttons(_("Xdx - Manual"),
+                   GTK_WINDOW(gui->window),
+                   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                   _("Close"),
+                   GTK_RESPONSE_CLOSE,
+                   NULL);
     gtk_widget_set_size_request(manualdialog, 650, 300);
 
     swindow = gtk_scrolled_window_new(NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(manualdialog)->vbox),
-                       swindow, TRUE, TRUE, 0);
+
+    vbox = gtk_dialog_get_content_area(GTK_DIALOG(manualdialog));
+    gtk_box_pack_start(GTK_BOX(vbox),swindow, TRUE, TRUE, 0);
+
     helptextview = gtk_text_view_new();
     gtk_text_view_set_editable(GTK_TEXT_VIEW(helptextview), FALSE);
     gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(helptextview), FALSE);
+    gtk_widget_set_margin_start(GTK_WIDGET(helptextview), 5);
+    gtk_widget_set_margin_end(GTK_WIDGET(helptextview), 5);
+    gtk_widget_set_margin_top(GTK_WIDGET(helptextview), 4);
+    gtk_widget_set_margin_bottom(GTK_WIDGET(helptextview), 8);
     gtk_container_add(GTK_CONTAINER(swindow), helptextview);
+
     buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(helptextview));
     gtk_text_buffer_get_start_iter(buffer, &iter);
 
@@ -111,8 +121,12 @@ on_manual_activate(GtkMenuItem *menuitem,
     }
 
     font_desc = pango_font_description_from_string("mono");
-    gtk_widget_modify_font(helptextview, font_desc);
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    gtk_widget_override_font(helptextview, font_desc);
+#pragma GCC diagnostic pop
     pango_font_description_free(font_desc);
+
     g_free(helpfile);
+
     gtk_widget_show_all(manualdialog);
 }
