@@ -66,37 +66,45 @@ void
 on_open_activate(GtkMenuItem    *menuitem,
                  gpointer        user_data)
 {
-    GtkWidget *opendialog, *hostnamecombo, *portcombo, *hbox, *stock, *table,
-              *hostlabel, *portlabel, *mainentry;
+    GtkWidget *opendialog, *hostnamecombo, *portcombo, *hbox, *vbox, *stock,
+              *grid, *hostlabel, *portlabel, *mainentry, *hnc_child, *pc_child,
+              *open_menu, *close_menu;
     gint i, num, response;
     GList *node;
+    extern GValue grid_spacing;
     gboolean result = FALSE;
     servertype *cluster;
     gchar *s;
 
     gtk_widget_set_sensitive(gui->window, 0);
-    opendialog = gtk_dialog_new_with_buttons(_("xdx - open connection"),
-                 GTK_WINDOW(gui->window),
-                 GTK_DIALOG_MODAL |
-                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                 GTK_STOCK_OK,
-                 GTK_RESPONSE_OK, NULL);
 
-    hbox = gtk_hbox_new(FALSE, 8);
-    gtk_container_set_border_width(GTK_CONTAINER(hbox), 8);
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(opendialog)->vbox), hbox, FALSE,
-                       FALSE, 0);
-    stock =
-        gtk_image_new_from_stock(GTK_STOCK_DIALOG_QUESTION,
+    opendialog = gtk_dialog_new_with_buttons(_("Xdx - Open connection"),
+                 GTK_WINDOW(gui->window),
+                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                 _("_Cancel"),
+                 GTK_RESPONSE_CANCEL,
+                 _("_OK"),
+                 GTK_RESPONSE_OK,
+                 NULL);
+
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_container_set_border_width(GTK_CONTAINER(hbox), 6);
+
+    vbox = gtk_dialog_get_content_area(GTK_DIALOG(opendialog));
+    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
+    stock = gtk_image_new_from_icon_name("dialog-question",
                                  GTK_ICON_SIZE_DIALOG);
     gtk_box_pack_start(GTK_BOX(hbox), stock, FALSE, FALSE, 0);
-    table = gtk_table_new(2, 2, FALSE);
-    gtk_table_set_row_spacings(GTK_TABLE(table), 4);
-    gtk_table_set_col_spacings(GTK_TABLE(table), 4);
-    gtk_box_pack_start(GTK_BOX(hbox), table, TRUE, TRUE, 0);
-    hostlabel = gtk_label_new_with_mnemonic(_("_Hostname"));
-    gtk_table_attach_defaults(GTK_TABLE(table), hostlabel, 0, 1, 0, 1);
+
+    grid = gtk_grid_new();
+    g_object_set_property(G_OBJECT(grid), "column-spacing", &grid_spacing);
+    g_object_set_property(G_OBJECT(grid), "row-spacing", &grid_spacing);
+    gtk_box_pack_start(GTK_BOX(hbox), grid, TRUE, TRUE, 0);
+
+    hostlabel = gtk_label_new(_("Hostname"));
+    gtk_grid_attach(GTK_GRID(grid), hostlabel, 0, 0, 1, 1);
+
     hostnamecombo = gtk_combo_box_text_new_with_entry();
 
     if (gui->hostnamehistory) {
@@ -108,9 +116,12 @@ on_open_activate(GtkMenuItem    *menuitem,
         }
     }
 
-    gtk_table_attach_defaults(GTK_TABLE(table), hostnamecombo, 1, 2, 0, 1);
-    portlabel = gtk_label_new_with_mnemonic(_("_Port"));
-    gtk_table_attach_defaults(GTK_TABLE(table), portlabel, 0, 1, 1, 2);
+    gtk_grid_attach(GTK_GRID(grid), hostnamecombo, 1, 0, 1, 1);
+
+    portlabel = gtk_label_new(_("Port"));
+    gtk_widget_set_halign(GTK_WIDGET(portlabel), GTK_ALIGN_END);
+    gtk_grid_attach(GTK_GRID(grid), portlabel, 0, 1, 1, 1);
+
     portcombo = gtk_combo_box_text_new_with_entry();
 
     if (gui->porthistory) {
@@ -122,21 +133,31 @@ on_open_activate(GtkMenuItem    *menuitem,
         }
     }
 
-    gtk_table_attach_defaults(GTK_TABLE(table), portcombo, 1, 2, 1, 2);
+    gtk_grid_attach(GTK_GRID(grid), portcombo, 1, 1, 1, 1);
+
     gtk_widget_show_all(hbox);
+
     gtk_widget_set_sensitive(gui->window, 0);
-    gtk_combo_box_set_active
-    (GTK_COMBO_BOX(portcombo), g_list_length(gui->porthistory) - 1);
-    gtk_combo_box_set_active
-    (GTK_COMBO_BOX(hostnamecombo), g_list_length(gui->hostnamehistory) - 1);
+
+    gtk_combo_box_set_active(GTK_COMBO_BOX(portcombo),
+                             g_list_length(gui->porthistory) - 1);
+
+    gtk_combo_box_set_active(GTK_COMBO_BOX(hostnamecombo),
+                             g_list_length(gui->hostnamehistory) - 1);
+
     response = gtk_dialog_run(GTK_DIALOG(opendialog));
 
+    open_menu = g_object_get_data(G_OBJECT(gui->window), "open_item");
+    close_menu= g_object_get_data(G_OBJECT(gui->window), "close_item");
+
     if (response == GTK_RESPONSE_OK) {
         cluster = g_object_get_data(G_OBJECT(gui->window), "cluster");
-        cluster->host = gtk_editable_get_chars
-                        (GTK_EDITABLE(GTK_BIN(hostnamecombo)->child), 0, -1);
-        cluster->port = gtk_editable_get_chars
-                        (GTK_EDITABLE(GTK_BIN(portcombo)->child), 0, -1);
+
+        hnc_child = gtk_bin_get_child(GTK_BIN(hostnamecombo));
+        cluster->host = gtk_editable_get_chars(GTK_EDITABLE(hnc_child), 0, -1);
+
+        pc_child = gtk_bin_get_child(GTK_BIN(portcombo));
+        cluster->port = gtk_editable_get_chars(GTK_EDITABLE(pc_child), 0, -1);
 
         if (!g_ascii_strcasecmp(cluster->host, ""))
             cluster->host = "localhost";
@@ -188,8 +209,8 @@ on_open_activate(GtkMenuItem    *menuitem,
             gui->porthistory = g_list_remove(gui->porthistory,
                                              g_list_last(gui->porthistory)->data);
 
-        menu_set_sensitive(gui->ui_manager, "/MainMenu/HostMenu/Open", FALSE);
-        menu_set_sensitive(gui->ui_manager, "/MainMenu/HostMenu/Close", FALSE);
+        gtk_widget_set_sensitive(GTK_WIDGET(open_menu), FALSE);
+        gtk_widget_set_sensitive(GTK_WIDGET(close_menu), FALSE);
 
         result = clresolve(cluster);
     }
@@ -200,8 +221,8 @@ on_open_activate(GtkMenuItem    *menuitem,
     gtk_widget_grab_focus(GTK_WIDGET(mainentry));
 
     if (!result) {
-        menu_set_sensitive(gui->ui_manager, "/MainMenu/HostMenu/Open", TRUE);
-        menu_set_sensitive(gui->ui_manager, "/MainMenu/HostMenu/Close", FALSE);
+        gtk_widget_set_sensitive(GTK_WIDGET(open_menu), TRUE);
+        gtk_widget_set_sensitive(GTK_WIDGET(close_menu), FALSE);
     }
 
 }
