@@ -64,15 +64,17 @@
 
 
 extern preferencestype preferences;
-GdkColormap *colormap;
+GdkVisual *visual;
 gchar *prompttagname, *calltagname;
 gchar *opt_cty_path = NULL;     /* For -c or --cty_path options. */
+guitype *gui;
+GValue grid_spacing = G_VALUE_INIT;
 
 int
 main(int argc, char *argv[])
 {
     GtkWidget *treeview, *maintext, *vpaned, *sidemenu, *reconnectmenu,
-              *highframe, *fkeysmenu, *fvbox,
+              *highframe, *fkeysmenu, *func_grid,
               *highcheck1, *highcheck2, *highcheck3, *highcheck4, *highcheck5,
               *highcheck6, *highcheck7, *highcheck8, *soundcheck,
               *highentry1, *highentry2, *highentry3, *highentry4, *highentry5,
@@ -80,7 +82,7 @@ main(int argc, char *argv[])
               *f1button, *f2button, *f3button, *f4button, *f5button, *f6button,
               *f7button, *f8button;
     GtkTreeViewColumn *column;
-    gchar **wsplit, *colorstr, *str;
+    gchar **wsplit, *str;
     GString *greeting = g_string_new("");
     PangoFontDescription *font_description;
     gint pango_size;
@@ -102,7 +104,12 @@ main(int argc, char *argv[])
     setlocale(LC_NUMERIC, "C");
     parse_opts(&argc, &argv);
 
-    colormap = gdk_colormap_get_system();
+    /* Application default spacing in pixels between children in grids. */
+    g_value_init(&grid_spacing, G_TYPE_INT);
+    g_value_set_int(&grid_spacing, 8);
+
+    visual = gdk_screen_get_system_visual(gdk_screen_get_default());
+
     create_mainwindow();
     dircheck();
     loadpreferences();
@@ -112,8 +119,9 @@ main(int argc, char *argv[])
     maintext = g_object_get_data(G_OBJECT(gui->window), "maintext");
     buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(maintext));
 
-    /* most of the tagnames are randomised when changed, so we can keep on using the old
-       tags without having to remove them from the tagtable */
+    /* most of the tagnames are randomised when changed, so we can keep on
+     * using the old tags without having to remove them from the tagtable
+     */
     gui->high1tagname = g_strdup("highcolor1");
     gui->high2tagname = g_strdup("highcolor2");
     gui->high3tagname = g_strdup("highcolor3");
@@ -122,54 +130,55 @@ main(int argc, char *argv[])
     gui->high6tagname = g_strdup("highcolor6");
     gui->high7tagname = g_strdup("highcolor7");
     gui->high8tagname = g_strdup("highcolor8");
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor1.red * 255 / 65535,
-                               preferences.highcolor1.green * 255 / 65535,
-                               preferences.highcolor1.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high1tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor2.red * 255 / 65535,
-                               preferences.highcolor2.green * 255 / 65535,
-                               preferences.highcolor2.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high2tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor3.red * 255 / 65535,
-                               preferences.highcolor3.green * 255 / 65535,
-                               preferences.highcolor3.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high3tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor4.red * 255 / 65535,
-                               preferences.highcolor4.green * 255 / 65535,
-                               preferences.highcolor4.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high4tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor5.red * 255 / 65535,
-                               preferences.highcolor5.green * 255 / 65535,
-                               preferences.highcolor5.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high5tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor6.red * 255 / 65535,
-                               preferences.highcolor6.green * 255 / 65535,
-                               preferences.highcolor6.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high6tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor7.red * 255 / 65535,
-                               preferences.highcolor7.green * 255 / 65535,
-                               preferences.highcolor7.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high7tagname, "foreground",
-                               colorstr, NULL);
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.highcolor8.red * 255 / 65535,
-                               preferences.highcolor8.green * 255 / 65535,
-                               preferences.highcolor8.blue * 255 / 65535);
-    gtk_text_buffer_create_tag(buffer, gui->high8tagname, "foreground",
-                               colorstr, NULL);
+
+    /* User selected colors for user defined word highlighting. */
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high1tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor1,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high2tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor2,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high3tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor3,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high4tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor4,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high5tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor5,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high6tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor6,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high7tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor7,
+                               NULL);
+
+    gtk_text_buffer_create_tag(buffer,
+                               gui->high8tagname,
+                               "foreground-rgba",
+                               &preferences.highcolor8,
+                               NULL);
 
     gui->prompttagname = g_strdup("prompt");
     gui->calltagname = g_strdup("call");
@@ -177,36 +186,37 @@ main(int argc, char *argv[])
     gui->senttagname = g_strdup("sent");
     gui->wxtagname = g_strdup("wx");
 
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.promptcolor.red * 255 / 65535,
-                               preferences.promptcolor.green * 255 / 65535,
-                               preferences.promptcolor.blue * 255 / 65535);
-    gtk_text_buffer_create_tag
-    (buffer, gui->prompttagname, "foreground", colorstr, NULL);
-    gtk_text_buffer_create_tag(buffer, gui->calltagname, "foreground",
-                               colorstr, "weight", PANGO_WEIGHT_BOLD, NULL);
+    /* User selected colors for Xdx defined string highlighting. */
+    gtk_text_buffer_create_tag(buffer,
+                               gui->prompttagname,
+                               "foreground-rgba",
+                               &preferences.promptcolor,
+                               NULL);
+    gtk_text_buffer_create_tag(buffer,
+                               gui->calltagname,
+                               "foreground-rgba",
+                               &preferences.promptcolor,
+                               "weight",
+                               PANGO_WEIGHT_BOLD,
+                               NULL);
 
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.wwvcolor.red * 255 / 65535,
-                               preferences.wwvcolor.green * 255 / 65535,
-                               preferences.wwvcolor.blue * 255 / 65535);
-    gtk_text_buffer_create_tag
-    (buffer, gui->wwvtagname, "foreground", colorstr, NULL);
+    gtk_text_buffer_create_tag(buffer,
+                               gui->wwvtagname,
+                               "foreground-rgba",
+                               &preferences.wwvcolor,
+                               NULL);
 
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.wxcolor.red * 255 / 65535,
-                               preferences.wxcolor.green * 255 / 65535,
-                               preferences.wxcolor.blue * 255 / 65535);
-    gtk_text_buffer_create_tag
-    (buffer, gui->wxtagname, "foreground", colorstr, NULL);
+    gtk_text_buffer_create_tag(buffer,
+                               gui->wxtagname,
+                               "foreground-rgba",
+                               &preferences.wxcolor,
+                               NULL);
 
-    colorstr = g_strdup_printf("#%02X%02X%02X",
-                               preferences.sentcolor.red * 255 / 65535,
-                               preferences.sentcolor.green * 255 / 65535,
-                               preferences.sentcolor.blue * 255 / 65535);
-    gtk_text_buffer_create_tag
-    (buffer, gui->senttagname, "foreground", colorstr, NULL);
-    g_free(colorstr);
+    gtk_text_buffer_create_tag(buffer,
+                               gui->senttagname,
+                               "foreground-rgba",
+                               &preferences.sentcolor,
+                               NULL);
 
     highcheck1 = g_object_get_data(G_OBJECT(gui->window), "highcheck1");
     highcheck2 = g_object_get_data(G_OBJECT(gui->window), "highcheck2");
@@ -278,27 +288,65 @@ main(int argc, char *argv[])
     if (g_ascii_strcasecmp(preferences.highword8, "?"))
         gtk_entry_set_text(GTK_ENTRY(highentry8), preferences.highword8);
 
-    gtk_widget_modify_text(highentry1, GTK_STATE_NORMAL, &preferences.highcolor1);
-    gtk_widget_modify_text(highentry2, GTK_STATE_NORMAL, &preferences.highcolor2);
-    gtk_widget_modify_text(highentry3, GTK_STATE_NORMAL, &preferences.highcolor3);
-    gtk_widget_modify_text(highentry4, GTK_STATE_NORMAL, &preferences.highcolor4);
-    gtk_widget_modify_text(highentry5, GTK_STATE_NORMAL, &preferences.highcolor5);
-    gtk_widget_modify_text(highentry6, GTK_STATE_NORMAL, &preferences.highcolor6);
-    gtk_widget_modify_text(highentry7, GTK_STATE_NORMAL, &preferences.highcolor7);
-    gtk_widget_modify_text(highentry8, GTK_STATE_NORMAL, &preferences.highcolor8);
+/* Suppress deprecated warnings until a solution using pango attributes is
+ * developed.
+ */
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    gtk_widget_override_color(highentry1,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor1);
+
+    gtk_widget_override_color(highentry2,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor2);
+
+    gtk_widget_override_color(highentry3,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor3);
+
+    gtk_widget_override_color(highentry4,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor4);
+
+    gtk_widget_override_color(highentry5,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor5);
+
+    gtk_widget_override_color(highentry6,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor6);
+
+    gtk_widget_override_color(highentry7,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor7);
+
+    gtk_widget_override_color(highentry8,
+                           GTK_STATE_FLAG_NORMAL,
+                           &preferences.highcolor8);
+#pragma GCC diagnostic pop
 
     treeview = g_object_get_data(G_OBJECT(gui->window), "treeview");
     vpaned = g_object_get_data(G_OBJECT(gui->window), "vpaned");
 
     font_description = pango_font_description_from_string(preferences.dxfont);
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
     gtk_widget_modify_font(GTK_WIDGET(treeview), font_description);
+#pragma GCC diagnostic pop
     pango_font_description_free(font_description);
+
     font_description = pango_font_description_from_string(preferences.allfont);
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
     gtk_widget_modify_font(GTK_WIDGET(maintext), font_description);
+#pragma GCC diagnostic pop
+
     pango_size = pango_font_description_get_size(font_description);
+
     /* line spacing is half character size */
-    g_object_set(G_OBJECT(maintext), "pixels-below-lines",
-                 PANGO_PIXELS(pango_size) / 2, NULL);
+    g_object_set(G_OBJECT(maintext),
+                 "pixels-below-lines",
+                 PANGO_PIXELS(pango_size) / 2,
+                 NULL);
+
     pango_font_description_free(font_description);
 
     wsplit = g_strsplit(preferences.columnwidths, ",", 0);
@@ -420,45 +468,56 @@ main(int argc, char *argv[])
     g_free(str);
 
     gtk_widget_show_all(gui->window);
+
     gtk_window_move(GTK_WINDOW(gui->window),
                     preferences.x, preferences.y);
+
     gtk_window_resize(GTK_WINDOW(gui->window),
                       preferences.width, preferences.height);
+
     gtk_paned_set_position(GTK_PANED(vpaned), preferences.handlebarpos);
 
-    fvbox = g_object_get_data(G_OBJECT(gui->window), "fvbox");
-    fkeysmenu = gtk_ui_manager_get_widget
-                (gui->ui_manager, "/MainMenu/SettingsMenu/Keybar");
+    func_grid = g_object_get_data(G_OBJECT(gui->window), "func_grid");
+    fkeysmenu = g_object_get_data(G_OBJECT(gui->window), "keybar_item");
 
     if (preferences.fbox == 0) {
-        gtk_widget_hide(fvbox);
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(fkeysmenu), FALSE);
+        gtk_widget_hide(func_grid);
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(fkeysmenu),
+                                       FALSE);
     } else {
-        gtk_widget_show(fvbox);
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(fkeysmenu), TRUE);
+        gtk_widget_show(func_grid);
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(fkeysmenu),
+                                       TRUE);
     }
 
     highframe = g_object_get_data(G_OBJECT(gui->window), "highframe");
-    sidemenu = gtk_ui_manager_get_widget
-               (gui->ui_manager, "/MainMenu/SettingsMenu/Sidebar");
+    sidemenu = g_object_get_data(G_OBJECT(gui->window), "sidebar_item");
 
     if (preferences.sidebar == 0) {
         gtk_widget_hide(highframe);
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sidemenu), FALSE);
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sidemenu),
+                                       FALSE);
     } else {
         gtk_widget_show(highframe);
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sidemenu), TRUE);
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(sidemenu),
+                                       TRUE);
     }
 
-    reconnectmenu = gtk_ui_manager_get_widget
-                    (gui->ui_manager, "/MainMenu/SettingsMenu/Reconnect");
+    reconnectmenu = g_object_get_data(G_OBJECT(gui->window), "reconnect_item");
 
-    if (preferences.reconnect == 0)
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(reconnectmenu), FALSE);
-    else
-        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(reconnectmenu), TRUE);
+    if (preferences.reconnect == 0) {
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(reconnectmenu),
+                                       FALSE);
+    } else {
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(reconnectmenu),
+                                       TRUE);
+    }
+
+    gtk_widget_set_sensitive(GTK_WIDGET(
+                             g_object_get_data(G_OBJECT(gui->window),
+                                                        "close_item")),
+                             FALSE);
 
-    menu_set_sensitive(gui->ui_manager, "/MainMenu/HostMenu/Close", FALSE);  /* do not translate */
     g_string_printf(greeting, _("Welcome to %s"), PACKAGE);
     updatestatusbar(greeting, FALSE);
     g_string_free(greeting, TRUE);
