@@ -70,24 +70,24 @@ typedef struct {
     gchar       *highword6;
     gchar       *highword7;
     gchar       *highword8;
-    GdkColor     highcolor1;
-    GdkColor     highcolor2;
-    GdkColor     highcolor3;
-    GdkColor     highcolor4;
-    GdkColor     highcolor5;
-    GdkColor     highcolor6;
-    GdkColor     highcolor7;
-    GdkColor     highcolor8;
+    GdkRGBA      highcolor1;
+    GdkRGBA      highcolor2;
+    GdkRGBA      highcolor3;
+    GdkRGBA      highcolor4;
+    GdkRGBA      highcolor5;
+    GdkRGBA      highcolor6;
+    GdkRGBA      highcolor7;
+    GdkRGBA      highcolor8;
     gchar       *highmenu;
     gint         sidebar;
     gint         fbox;
     gint         reconnect;
     gint         playsound;
     gint         keepalive;
-    GdkColor     promptcolor;
-    GdkColor     sentcolor;
-    GdkColor     wwvcolor;
-    GdkColor     wxcolor;
+    GdkRGBA      promptcolor;
+    GdkRGBA      sentcolor;
+    GdkRGBA      wwvcolor;
+    GdkRGBA      wxcolor;
     gchar       *f1command;
     gchar       *f2command;
     gchar       *f3command;
